# Package contains plugins not built with libtool, and does not contain
# any shared libraries, so disable underlinking checks - AdamW 2008/07
%define _disable_ld_no_undefined 1

%define name	amsn
%define version	0.97.2
%define pre	0
%define svn	0
%define rel	3
%if %pre
%define release		%mkrel -c %pre %rel
%define distname	http://prdownloads.sourceforge.net/%{name}/%{name}-%{version}%{pre}.tar.bz2
%define dirname		%{name}-%{version}%{pre}
%else
%if %svn
%define release		%mkrel 0.RC1.%svn.%rel
%define distname	http://www.amsn-project.net/amsn_dev.tar.gz
%define dirname		msn
%else
%define release		%mkrel %rel
%define distname	http://prdownloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
%define dirname		%{name}-%{version}
%endif
%endif

Summary:	MSN Messenger clone for Linux
Summary(fr):	Clne MSN Messenger pour Linux
Summary(de):	MSN Messenger-Klon fr Linux
Name:		%{name}
Version:	%{version}
Release:	%{release}
License:	GPLv2+
Group:		Networking/Instant messaging
URL:		http://amsn.sourceforge.net/
Source0:	%{distname}
Source2:	amsn-0.97-startup
Patch0:		amsn-0.95-www-browser.diff
BuildRequires:	tcl >= 8.5
BuildRequires:	openssl-devel
BuildRequires:	tk >= 8.5
BuildRequires:  tcl-devel >= 8.5
BuildRequires:	tk-devel >= 8.5
BuildRequires:  automake
BuildRequires:	ImageMagick
BuildRequires:  desktop-file-utils
BuildRequires:  png-devel
BuildRequires:  jpeg-devel
Requires:	tcl >= 8.5
Requires:	tk >= 8.5
Requires:	%{mklibname tcltls 1.50}
Requires:       soundwrapper
Requires:	tcl-snack
BuildRoot:	%{_tmppath}/buildroot-%{name}-%{version}

%description
AMSN is a Microsoft Messenger (MSN) clone for Unix, Windows and 
Macintosh platforms. It supports file transfers, groups, video,
voice and many more features.

%description -l fr
amsn est un client Microsoft Messenger (MSN) pour UNIX, Windows et
Macintosh écrit en Tcl/Tk.  Il supporte les tranferts de fichiers, les
groupes et beaucoup d'autres possibilités. 
Visitez http://amsn.sourceforge.net/ pour de plus amples dtails.

%description -l de
amsn ist ein Microsoft Messenger (MSN) Client fr UNIX, Windows und
Macintosh, der in Tcl/Tk geschrieben ist. Es untersttzt
Dateibertragungen, Gruppen uvm.
Begeben Sie sich auf http://amsn.sourceforge.net/ um mehr ber dieses
Projekt zu erfahren.

%prep

%setup -q -n %{dirname}
%patch0 -p0 -b .www-browser

# lib64 fixes
perl -pi -e "s|/usr/lib/|%{_libdir}|g" configure*
perl -pi -e "s|/lib\b|/%{_lib}|g" configure*
perl -pi -e "s|^set libtls .*|set libtls \"%{_libdir}/tls1.50\"|g" amsn

%build
rm -f configure
libtoolize --copy --force; aclocal; autoconf --force

%configure2_5x --enable-alsa

%make

%install
rm -rf %{buildroot}

%makeinstall_std

install -d %{buildroot}%{_bindir}
rm -f %{buildroot}%{_bindir}/amsn
install -m0755 %{SOURCE2} %{buildroot}%{_bindir}/amsn

# fix softlinks
pushd %{buildroot}%{_bindir}
    ln -snf %{_datadir}/amsn/amsn-remote amsn-remote
    ln -snf %{_datadir}/amsn/amsn-remote-CLI amsn-remote-CLI
popd

ln -sf %{_docdir}%{name}-%{version}/README %{buildroot}%{_datadir}/amsn/README
ln -sf %{_docdir}%{name}-%{version}/HELP %{buildroot}%{_datadir}/amsn/HELP

# Menu
perl -pi -e 's,%{name}.png,%{name},g' %{buildroot}%{_datadir}/amsn/amsn.desktop
desktop-file-install --vendor="" \
  --remove-key="Encoding" \
  --remove-key="Info" \
  --remove-category="Application" \
  --remove-key='Info' \
  --remove-key='Encoding' \
  --add-category="Network" \
  --add-category="InstantMessaging" \
  --add-category="X-MandrivaLinux-CrossDesktop" \
  --dir %{buildroot}%{_datadir}/amsn %{buildroot}%{_datadir}/amsn/amsn.desktop

mkdir -p %{buildroot}%{_datadir}/applications
cp  %{buildroot}%{_datadir}/amsn/amsn.desktop %{buildroot}%{_datadir}/applications/amsn.desktop

#icons
mkdir -p %{buildroot}/%_iconsdir/hicolor/{128x128,96x96,72x72,64x64,48x48,32x32,22x22,16x16}/apps
install -m644 desktop-icons/128x128/apps/%{name}.png %{buildroot}/%_iconsdir/hicolor/128x128/apps/%name.png
install -m644 desktop-icons/96x96/apps/%{name}.png %{buildroot}/%_iconsdir/hicolor/96x96/apps/%name.png
install -m644 desktop-icons/72x72/apps/%{name}.png %{buildroot}/%_iconsdir/hicolor/72x72/apps/%name.png
install -m644 desktop-icons/64x64/apps/%{name}.png %{buildroot}/%_iconsdir/hicolor/64x64/apps/%name.png
install -m644 desktop-icons/48x48/apps/%{name}.png %{buildroot}/%_iconsdir/hicolor/48x48/apps/%name.png
install -m644 desktop-icons/32x32/apps/%{name}.png %{buildroot}/%_iconsdir/hicolor/32x32/apps/%name.png
install -m644 desktop-icons/22x22/apps/%{name}.png %{buildroot}/%_iconsdir/hicolor/22x22/apps/%name.png
install -m644 desktop-icons/16x16/apps/%{name}.png %{buildroot}/%_iconsdir/hicolor/16x16/apps/%name.png

# cleanup
rm -rf %{buildroot}%{_datadir}/amsn/HELP
rm -rf %{buildroot}%{_datadir}/amsn/README
rm -f %{buildroot}%{_datadir}/amsn/sndplay

%if %mdkversion < 200900
%post
%update_menus
%update_icon_cache hicolor
%endif

%if %mdkversion < 200900
%postun
%clean_menus
%clean_icon_cache hicolor
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc AGREEMENT CREDITS FAQ GNUGPL HELP README TODO
%{_bindir}/%{name}
%{_bindir}/%{name}-remote
%{_bindir}/%{name}-remote-CLI
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/*
%{_datadir}/pixmaps/*



%changelog
* Tue Oct 21 2008 Adam Williamson <awilliamson@mandriva.com> 0.97.2-3mdv2009.0
+ Revision: 296304
- can't use -M to fix #39273 as it's invalid for anything but padsp: instead
  directly set PADSP_NO_MIXER, which is what -M does
- fix #39273 (fix high CPU usage by soundwrapper by using -M parameter)

* Mon Aug 04 2008 Frederik Himpe <fhimpe@mandriva.org> 0.97.2-1mdv2009.0
+ Revision: 263306
- update to new version 0.97.2

* Wed Jul 02 2008 Adam Williamson <awilliamson@mandriva.com> 0.97.1-1mdv2009.0
+ Revision: 230821
- disable underlink checking (breaks on plugins, and package contains no shared libs)
- bit of spec cleaning
- new release 0.97.1

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Sat Feb 09 2008 Frederik Himpe <fhimpe@mandriva.org> 0.97-2mdv2008.1
+ Revision: 164480
- Rebuild against new tk 8.5.1 (fixes bug #37624)

  + Adam Williamson <awilliamson@mandriva.com>
    - damn, missed the -devel buildrequires
    - version the tcl / tk buildrequires to 8.5 for the 2008.0 backport

* Fri Dec 28 2007 Nicolas Lécureuil <neoclust@mandriva.org> 0.97-1mdv2008.1
+ Revision: 138861
- New version 0.97

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Nov 12 2007 Adam Williamson <awilliamson@mandriva.com> 0.97-0.RC1.20071112.1mdv2008.1
+ Revision: 108305
- requires tcl-snack (required for audio chat to work, thanks Philippe Didier)
- new snapshot 20071112

* Thu Sep 06 2007 Adam Williamson <awilliamson@mandriva.com> 0.97-0.RC1.20070905.2mdv2008.0
+ Revision: 80724
- drop legacy icons
- fix menu entry issues
- update to current svn (more stable than RC1 as per austin)

* Sun Sep 02 2007 Funda Wang <fundawang@mandriva.org> 0.97-0.RC1.2mdv2008.0
+ Revision: 77745
- add X-MandrivaLinux-CrossDesktop for amsn (bug#33061).
  Because it sits in contrib without distro flavour, it is very likely
  that users install it manually. Due to it is not a GTK/Qt applications,
  it will listed in Others forever without CrossDesktop.

  + Adam Williamson <awilliamson@mandriva.com>
    - revert previous change by blindauer (the req was already there)

  + Emmanuel Blindauer <blindauer@mandriva.org>
    - Added requires for libtcltls, or amsn won't connect.

* Tue Jun 12 2007 Adam Williamson <awilliamson@mandriva.com> 0.97-0.RC1.1mdv2008.0
+ Revision: 38334
- add fd.o icons
- small spec clean
- new release 0.97RC1

  + Nicolas Lécureuil <neoclust@mandriva.org>
    - Add --enable-alsa configure option to fix sound problems

* Wed Apr 25 2007 Gustavo De Nardin <gustavodn@mandriva.com> 0.96-3mdv2008.0
+ Revision: 18126
- rebuild for libtcl/tk 8.5


* Sat Dec 23 2006 Nicolas Lécureuil <neoclust@mandriva.org> 0.96-2mdv2007.0
+ Revision: 101910
- Fix BuildRequires

  + plouf <plouf>
    - Fix BuilRequires on libpng-devel
    - New release 0.96

* Mon Oct 16 2006 Nicolas Lécureuil <neoclust@mandriva.org> 0.95-9mdv2006.0
+ Revision: 65425
- Add BuildRequires

  + plouf <plouf>
    - add Requires on soundwrapper
    - Import amsn

